==> nextcloud-28.0.14.tgz: nextcloud/apps/files_reminders/l10n/sv.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Filpåminnelser",
    "Reminder for {name}" : "Påminnelse för {name}",
    "View file" : "Visa fil",
    "View folder" : "Visa mapp",
    "Set file reminders" : "Ställ in filpåminnelser",
    "We will remind you of this file" : "Vi kommer att påminna dig om denna fil",
    "Please choose a valid date & time" : "Välj ett giltigt datum och tid",
    "Cancel" : "Avbryt",
    "Clear reminder" : "Rensa påminnelse",
    "Set reminder" : "Ställ in påminnelse",
    "Set reminder for \"{fileName}\"" : "Ställ in påminnelse för \"{fileName}\"",
    "Set reminder at custom date & time" : "Ställ in påminnelse vid anpassat datum och tid",
    "Reminder set for \"{fileName}\"" : "Påminnelse inställd för \"{fileName}\"",
    "Failed to set reminder" : "Kunde inte ställa in påminnelsen",
    "Reminder cleared for \"{fileName}\"" : "Påminnelse borttagen för \"{fileName}\"",
    "Failed to clear reminder" : "Kunde inte rensa påminnelsen",
    "Reminder set" : "Påminnelse inställd",
    "Set custom reminder" : "Ställ in anpassad påminnelse",
    "Later today" : "Senare idag",
    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
    "Tomorrow" : "I morgon",
    "Set reminder for tomorrow" : "Ställ in påminnelse för imorgon",
    "This weekend" : "Denna helgen",
    "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
    "Next week" : "Nästa vecka",
    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Filpåminnelser**\n\nStäll in filpåminnelser."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/files_reminders/l10n/sv.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Filpåminnelser",
    "Reminder for {name}" : "Påminnelse för {name}",
    "View file" : "Visa fil",
    "View folder" : "Visa mapp",
    "Set file reminders" : "Ställ in filpåminnelser",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Filpåminnelser**\n\nStäll in filpåminnelser.",
    "We will remind you of this file" : "Vi kommer att påminna dig om denna fil",
    "Please choose a valid date & time" : "Välj ett giltigt datum och tid",
    "Cancel" : "Avbryt",
    "Clear reminder" : "Rensa påminnelse",
    "Set reminder" : "Ställ in påminnelse",
    "Set reminder for \"{fileName}\"" : "Ställ in påminnelse för \"{fileName}\"",
    "Set reminder at custom date & time" : "Ställ in påminnelse vid anpassat datum och tid",
    "Reminder set for \"{fileName}\"" : "Påminnelse inställd för \"{fileName}\"",
    "Failed to set reminder" : "Kunde inte ställa in påminnelsen",
    "Reminder cleared for \"{fileName}\"" : "Påminnelse borttagen för \"{fileName}\"",
    "Failed to clear reminder" : "Kunde inte rensa påminnelsen",
    "Reminder set" : "Påminnelse inställd",
    "Set custom reminder" : "Ställ in anpassad påminnelse",
    "Later today" : "Senare idag",
    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
    "Tomorrow" : "I morgon",
    "Set reminder for tomorrow" : "Ställ in påminnelse för imorgon",
    "This weekend" : "Denna helgen",
    "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
    "Next week" : "Nästa vecka",
    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka"
},
"nplurals=2; plural=(n != 1);");
